@@ -166,7 +166,8 @@ class FeedManager(gobject.GObject):
 
         # 200 == OK, and 3xx are redirections.
         # On the other hand bozo==1 if there was some problem parsing the feed
-        if (new_feed_data.status!=200 and new_feed_data.status/100 != 3) or \
+        if 'status' not in new_feed_data or \
+                (new_feed_data.status!=200 and new_feed_data.status/100 != 3) or \
                 new_feed_data.bozo:
             del new_feed_data
             raise IOError('Resource is not a feed')
