@@ -1238,11 +1238,19 @@ class EntriesWindow(hildon.StackableWindow):
         model = self.view.get_model().get_model()
         for entry in self.feed_data.entries:
             entry_iter = model.append()
+            if 'updated_parsed' in entry:
+                date = entry.updated_parsed
+            elif 'published_parsed' in entry:
+                date = entry.published_parsed
+            elif 'created_parsed' in entry:
+                date = entry.created_parsed
+            else:
+                date = 0
             model.set(entry_iter,
                       self.ENTRIES_MODEL_TEXT_COLUMN, self.view.get_visual_entry_text(entry),
                       self.ENTRIES_MODEL_DATA_COLUMN, entry,
                       self.ENTRIES_MODEL_DATE_COLUMN, self.view.get_visual_entry_date(entry),
-                      self.ENTRIES_MODEL_DATE_PARSED_COLUMN, calendar.timegm(entry.updated_parsed))
+                      self.ENTRIES_MODEL_DATE_PARSED_COLUMN, calendar.timegm(date) if date else 0)
 
     def _on_connection_changed(self, conn_manager):
         if conn_manager.is_online():
@@ -1251,12 +1259,12 @@ class EntriesWindow(hildon.StackableWindow):
             if 'itunes' in self.feed_data.namespaces:
                 self._download_all_button.show()
             self._sync_feed_button.show()
-            hildon.GtkTreeView.set_action_area_visible(self.view, True)
+            self.view.set_action_area_visible(True)
         else:
             self._update_feed_button.hide()
             self._download_all_button.hide()
             self._sync_feed_button.hide()
-            hildon.GtkTreeView.set_action_area_visible(self.view, False)
+            self.view.set_action_area_visible(False)
 
     def _create_menu(self):
         menu = hildon.AppMenu()
@@ -1356,9 +1364,8 @@ class EntriesWindow(hildon.StackableWindow):
             hildon.hildon_banner_show_information(self, '', _('Error syncing read status with Google Reader'))
             return
 
-        model = self.view.get_model()
-        model.clear()
-        self._draw_entries()
+        self.view.get_model().get_model().clear()
+        self._add_entries()
 
         hildon.hildon_gtk_window_set_progress_indicator(self, False)
         self._update_feed_button.set_sensitive(True)
@@ -1467,8 +1474,8 @@ class EntriesWindow(hildon.StackableWindow):
             self._update_feed_button.set_sensitive(True)
             # No need to update self.feed_data as it is automatically updated.
             # The same happens with the reference stored in the FeedsWindow :-)
-            self.view.get_model().clear()
-            self._draw_entries()
+            self.view.get_model().get_model().clear()
+            self._add_entries()
 
     def _download_all_items_cb(self, button):
         folder = self.settings.auto_download_folder
@@ -1785,6 +1792,10 @@ class ItemWindow(hildon.StackableWindow):
             if 'summary_detail' in item and 'type' in item.summary_detail:
                 content_type = item.summary_detail.type
             body = item.summary
+        elif 'title' in item:
+            # Yeah I know..., but some weird feeds provide their
+            # content in the title. I want to support them anyway
+            body = item.title
         else:
             # Should never happen
             body = _('No text')
